@@ -1,9 +1,10 @@
 from .arithmetic import Add, Sub, Mul, Div, Pow, add, sub, mul, div, pow
 from .math import Log, Exp, Sin, Cos, Tan, Sqrt, Cbrt, Log10, Log2, Abs, Clip, log, exp, sin, cos, tan, sqrt, cbrt, log10, log2, abs, clip
-from .linalg import MatMul, TensorDot, Transpose, EinSum, matmul, dot, tensordot, einsum, transpose
+from .linalg import MatMul, Linear, TensorDot, Transpose, EinSum, matmul, linear, dot, tensordot, einsum, transpose
 from .tensor_ops import Reshape, Flatten, Squeeze, ExpandDims, Pad, SlidingWindowView, \
 reshape, flatten, squeeze, expand_dims, pad, sliding_window_view, newaxis
 from .reductions import Sum, Mean, Max, Min, Std, Var, sum, mean, max, min, std, var
 from .activations import ReLU, LeakyReLU, ReLU6, Sigmoid, Softmax, Tanh, relu, leaky_relu, relu6, sigmoid, softmax, tanh
+from .normalize import BatchNormalizer, batch_normalize 
 from .base import Function
-from .conv import conv2d, pool2d, maxpool2d, averagepool2d, pooling2d, maxpooling2d, averagepooling2d
+from .conv import conv2d, pool2d, maxpool2d, averagepool2d, pooling2d, maxpooling2d, averagepooling2d
\ No newline at end of file
